@@ -25,7 +25,9 @@ StandardBackendUpdater::StandardBackendUpdater(AbstractResourcesBackend *parent)
     connect(m_backend, &AbstractResourcesBackend::fetchingChanged, this, &StandardBackendUpdater::refreshUpdateable);
     connect(m_backend, &AbstractResourcesBackend::resourcesChanged, this, &StandardBackendUpdater::resourcesChanged);
     connect(m_backend, &AbstractResourcesBackend::resourceRemoved, this, [this](AbstractResource *resource) {
-        m_upgradeable.remove(resource);
+        if (m_upgradeable.remove(resource)) {
+            Q_EMIT updatesCountChanged(updatesCount());
+        }
         m_toUpgrade.remove(resource);
     });
     connect(TransactionModel::global(), &TransactionModel::transactionRemoved, this, &StandardBackendUpdater::transactionRemoved);
@@ -58,7 +60,7 @@ void StandardBackendUpdater::start()
     });
 
     const bool couldCancel = m_canCancel;
-    foreach (AbstractResource *res, upgradeList) {
+    for (AbstractResource *res : qAsConst(upgradeList)) {
         m_pendingResources += res;
         auto t = m_backend->installApplication(res);
         t->setVisible(false);
